@@ -188,6 +188,7 @@ my %determiners = (
     'ArrowHeadProperties' => {  },
     'Axes' => {  },
     'Axis' => {  },
+    'AxisType' => {  },
     'BlurEffect' => {  },
     'Camera' => {  },
     'ChartCategory' => {  },
@@ -195,6 +196,7 @@ my %determiners = (
     'ChartSeriesGroup' => {  },
     'ChartTitle' => {  },
     'ChartWall' => {  },
+    'ChartWallType' => {  },
     'CommonSlideViewProperties' => {  },
     'CustomDashPattern' => {  },
     'DataPoint' => {  },
